#
# spec file for package dnsproxy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dnsproxy
Version:        0.56.3
Release:        1.1
Summary:        A DNS proxy server
License:        Apache-2.0
Group:          Productivity/Networking/DNS/Utilities
URL:            https://github.com/AdguardTeam/dnsproxy
Source:         dnsproxy-%{version}.tar
Source1:        vendor.tar.zstd
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.20

%description
A DNS proxy server that supports numerous protocols, including
DNS-over-TLS, DNS-over-HTTPS, DNSCrypt, and DNS-over-QUIC. Moreover,
it can work as a DNS-over-HTTPS, DNS-over-TLS or DNS-over-QUIC
server.

%prep
%autosetup -p1 -a1

%build
go build \
   -mod=vendor \
%ifnarch ppc64 # Does not support pie
   -buildmode=pie
%endif

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Mon Oct 23 2023 eyadlorenzo@gmail.com
- Update to version 0.56.3:
  * Pull request 287: 4977-proxy-multiple-reserved-upstreams
* Wed Oct 18 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.56.2:
  * Fixed: quic-go has been updated to fix QUIC issues on FreeBSD. (Pull request 291)
  * Pull request 289: updated dependencies
  * Pull request 288: close bootstraps
* Sat Oct 14 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.56.1:
  * Fixed:
    Queries of DS type incorrectly routed to the exactly matched
    domain-specific upstream as opposed to RFC 4035 Section 2.4
    recommendations.
- Update to version 0.56.0:
  * Updated quic-go@v0.37.4 dependency to quic-go@v0.38.1.
* Thu Sep 21 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.55.0:
  * Pull request 283: upd quic-go and golibs
  * Pull request 281: use hostsfile
  * Pull request 282: 350 fix dns64 validation
  * Pull request: AG-24891: lint code imp
  * Pull request: AG-24891: skel-scripts
  * Pull request 278: Log upstream error
  * Pull request 277: upd quic-go
* Thu Aug 17 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Revert Use make for building as specified in the upstream
  README.md. Go applications typically need only a few lines for
  their go build command. Keeping that listing in the .spec makes
  it easier for mainainers to review relevant changes and normalize
  to our build conventions. Makefiles for Go applications are often
  building docker images and other steps not relevant to distro
  packaging, or that may not work inside OBS e.g. network access.
* Thu Aug 17 2023 eyadlorenzo@gmail.com
- Update to version 0.54.0:
  * all: update quic-go with version compatible with go1.21
- Use make for building, as specified in the upstream README.md
* Wed Aug  9 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.53.1:
  * Pull request 276: Sort hotfix
  * Pull request 275: Upd Go
  * Fix review comments
  * Update Dockerfile: fix wrong path
  * Update Dockerfile: fix wrong path
  * Update Docker README.md
  * Update Dockerfile
  * Pull request 272: AG-24087-global-root-cas
  * Pull request 271: Fix 208
* Tue Jul 18 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.52.0:
  * Pull request 269: Retry request for stale H3 clients.
  * Pull request 268: AG-23887-upd-quic-go
  * all: imp header setting
  * add https-server-name option to usage output
  * change default Server header of HTTPS server to 'dnsproxy'
  * make Server header for DoH server configurable
  * Pull request 266: fix-golangci-lint
  * Pull request 265: upd-specs
* Mon Jul  3 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.51.0:
  * Pull request 264: AGDNS-1528 fallback ups conf
  * Pull request: 5285-doq-errors
  * Pull request 261: 333-opt-timeout
* Thu Jun 15 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.50.2:
  * Pull request 260: 5872-fix-dnscrypt-reset
  * Pull request 259: 5874-fix-fallback
  * Pull request 258: 5874-openwrt-setsockopt
- Allow ppc64 to compile by not using pie
- Remove %%{go_nostrip} macro which is no longer recommended
- Drop Requires: golang-packaging. The original macros for file
  movements into GOPATH are obsolete with Go modules. Macro
  go_nostrip is no longer needed with current binutils and Go.
- Add BuildRequires: golang(API) >= 1.19 (min version per go.mod)
  This or metapackage BuildRequires: go are recommended to pull in
  the Go toolchain.
* Tue Jun  6 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.50.0:
  * Pull request 257: 331-upd-quic-go
  * Pull request 256: fix-poisoning
  * Pull request: proxy: fix edns cache
  * Pull request 254: depr-more-util
* Wed May 17 2023 Jan Engelhardt <jengelh@inai.de>
- Trim filler and time-sensitive wording
* Mon May 15 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.49.1:
  * Pull request 253: 324 refactor upstream
  * Pull request 252: AGDNS-1433-reuseport
  * Pull request 251: 324-refactor-bootstrap
  * Pull request 250: 4262-ipv6-pref
  * Pull request 249: 5631-lookup-panic
  * proxy: imp fmt
  * Prevent reading from a nil response in DNS64
  * Pull request 247: upd-all
